@@ -20,7 +20,7 @@
 #ifndef _ArcBall_h
 #define _ArcBall_h
 
-#include <QtGlobal>
+#include <QtSystemDetection>
 
 #ifdef Q_OS_MAC
 #include <OpenGL/gl.h>
@@ -42,6 +42,9 @@
 #ifdef _DEBUG
 # include "assert.h"
 #else
+#  ifdef assert
+#    undef assert
+#  endif
 # define assert(x) { }
 #endif
 
