@@ -130,7 +130,7 @@ void WelcomeScreen::onCurrentVariantChange() {
 }
 
 void WelcomeScreen::getNewVariant() {
-	KMessageBox::information(this, i18n("GetNewVariant not implemented"), QLatin1String(""));
+	KMessageBox::information(this, i18n("GetNewVariant not implemented"));
 }
 
 void WelcomeScreen::configureVariant() {
@@ -143,13 +143,13 @@ void WelcomeScreen::configureVariant() {
 void WelcomeScreen::startEmptyGame() {
 	GameVariant* variant = selectedVariant();
 	if(!variant) {
-		KMessageBox::error(this, i18n("Please select a puzzle variant."), i18n("Unable to start puzzle"));
+		KMessageBox::error(this, i18n("Please select a puzzle variant."), i18nc("@title:window", "Unable to Start Puzzle"));
 		return;
 	}
 	
 	Game game = variant->startEmpty();
 	if (! game.isValid()) {
-		KMessageBox::error(this, i18n("Unable to create an empty puzzle of the chosen variant; please try another."), i18n("Unable to start puzzle"));
+		KMessageBox::error(this, i18n("Unable to create an empty puzzle of the chosen variant; please try another."), i18nc("@title:window", "Unable to Start Puzzle"));
 		return;
 	}
 	
@@ -160,13 +160,13 @@ void WelcomeScreen::playVariant() {
 	return;		// Disable old game-creation code.
 	GameVariant* variant = selectedVariant();
 	if(!variant) {
-		KMessageBox::error(this, i18n("Please select a puzzle variant."), i18n("Unable to start puzzle"));
+		KMessageBox::error(this, i18n("Please select a puzzle variant."), i18nc("@title:window", "Unable to Start Puzzle"));
 		return;
 	}
 	
 	Game game = variant->createGame(difficulty(), 0);
 	if(!game.isValid()) {
-		KMessageBox::error(this, i18n("Unable to start a puzzle of the chosen variant; please try another."), i18n("Unable to start puzzle"));
+		KMessageBox::error(this, i18n("Unable to start a puzzle of the chosen variant; please try another."), i18nc("@title:window", "Unable to Start Puzzle"));
 		return;
 	}
 
@@ -176,13 +176,13 @@ void WelcomeScreen::playVariant() {
 void WelcomeScreen::generatePuzzle() {
 	GameVariant* variant = selectedVariant();
 	if(!variant) {
-		KMessageBox::error(this, i18n("Please select a puzzle variant."), i18n("Unable to start puzzle"));
+		KMessageBox::error(this, i18n("Please select a puzzle variant."), i18nc("@title:window", "Unable to Start Puzzle"));
 		return;
 	}
 
 	Game game = variant->createGame(difficulty(), symmetry());
 	if(!game.isValid()) {
-		KMessageBox::error(this, i18n("Unable to generate a puzzle of the chosen variant; please try another."), i18n("Unable to start puzzle"));
+		KMessageBox::error(this, i18n("Unable to generate a puzzle of the chosen variant; please try another."), i18nc("@title:window", "Unable to Start Puzzle"));
 		return;
 	}
 
